#!/usr/bin/env Rscript
args = commandArgs(trailingOnly = TRUE)

# Author: N.Pérez-Zanón 26th July 2021
# execution: Rscript OperationalCS.R conf_user.yml recipe.yml
# This code should process and check the recipe and build the workflow
print(args)
library(yaml)

# To test:
# args <- NULL; args[1] <- "recipes/conf_user.yml"; args[2] <- "recipes/seasonal_oper.yml"
# args <- NULL; args[1] <- "recipes/conf_user.yml"; args[2] <- "recipes/seasonal_complex.yml"

conf <- read_yaml(args[1])
recipe <- read_yaml(args[2])

# Load required libraries
source("tools/libs.R")

# Create output folder and log:
logger <- prepare_outputs(recipe = recipe, file = args[2], conf = conf) 

# Checks:
check_conf(conf, file = args[1], logger) 
verifications <- check_recipe(recipe, file = args[2], conf, logger) 

# Hace falta dividir por horizonte? Espero que no! 
# De momento aquí se queda esto: 
if (tolower(recipe$Analysis$Horizon) == 'seasonal') { 
  source("modules/seasonal_verifications.R")
} else if (tolower(recipe$Analysis$Horizon == 'subseasonal') {
  source("modules/subseasonal_verifications.R")
} else if (tolower(recipe$Analysis$Horizon == 'decadal') { 
  source("modules/decadal_verifications.R")
} else {
  error(logger, "Unknown 'Horizon' defined in the recipe.")
}

